@@ -36,28 +36,28 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-//@line 40 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 40 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
-//@line 46 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 46 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/3.1.1");
+pref("general.useragent.extra.thunderbird", "Thunderbird/3.1.7");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 56 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 56 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 pref("mail.rights.version", 0);
 
 // Don't show the about:rights notification in debug or non-official builds.
-//@line 66 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 66 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 71 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 71 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("nglayout.enable_drag_images", false);
-//@line 73 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 73 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // App-specific update preferences
 
@@ -121,8 +121,8 @@ pref("app.support.baseURL", "http://support.live.mozillamessaging.com/%LOCALE%/%
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
-pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/2/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/");
-pref("extensions.blocklist.detailsURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/");
+pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
 
 // Developers can set this to |true| if they are constantly changing files in their
 // extensions directory so that the extension system does not constantly think that
@@ -155,16 +155,15 @@ pref("extensions.{972ce4c6-7e08-4474-a285-3208198ce6fd}.description", "chrome://
 
 // Preferences for the Get Add-ons pane
 pref("extensions.getAddons.showPane", true);
-pref("extensions.getAddons.browseAddons", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%");
+pref("extensions.getAddons.browseAddons", "https://addons.mozilla.org/%LOCALE%/%APP%");
 pref("extensions.getAddons.maxResults", 5);
-pref("extensions.getAddons.recommended.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/recommended");
+pref("extensions.getAddons.recommended.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/recommended");
 pref("extensions.getAddons.recommended.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/list/featured/all/10/%OS%/%VERSION%");
-pref("extensions.getAddons.search.browseURL", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/search?q=%TERMS%");
+pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/search?q=%TERMS%");
 pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/10/%OS%/%VERSION%");
 
-pref("xpinstall.whitelist.add", "update.mozilla.org");
+pref("xpinstall.whitelist.add", "addons.mozilla.org");
 pref("xpinstall.whitelist.add.36", "getpersonas.com");
-pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
 pref("mail.shell.checkDefaultClient", true);
 pref("mail.spellcheck.inline", true);
@@ -181,11 +180,11 @@ pref("mail.last_msg_movecopy_target_uri", "");
 // last move or copy operation was a move
 pref("mail.last_msg_movecopy_was_move", true);
 
-//@line 199 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 198 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 204 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 203 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 206 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 205 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 pref("browser.download.show_plugins_in_list", false);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -261,9 +260,9 @@ pref("offline.send.unsent_messages",            0);
 // 2 Never synchronize the offline store when going offline
 pref("offline.download.download_messages",  0);
 
-//@line 282 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 281 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("offline.autoDetect", false);
-//@line 288 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 287 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // Expose only select protocol handlers. All others should go
 // through the external protocol handler route.
@@ -343,7 +342,7 @@ pref("mail.directory",                  "");
 pref("news.directory",                  "");
 pref("spellchecker.dictionary", "");
 // Dictionary download preference
-pref("spellchecker.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/dictionaries/");
+pref("spellchecker.dictionaries.download.url", "https://addons.mozilla.org/%LOCALE%/%APP%/dictionaries/");
 
 // profile.force.migration can be used to bypass the migration wizard, forcing migration from a particular
 // mail application without any user intervention. Possible values are: 
@@ -379,7 +378,8 @@ pref("browser.safebrowsing.provider.0.reportErrorURL", "http://{moz:locale}.phis
 pref("browser.safebrowsing.provider.0.reportPhishURL", "http://{moz:locale}.phish-report.mozilla.com/?hl={moz:locale}");
 
 // FAQ URL
-pref("browser.safebrowsing.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+// XXX Firefox is hard-coded because we haven't got our own version yet.
+pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
 
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
@@ -416,15 +416,15 @@ pref("mail.tabs.closeButtons", 1);
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
 // OS Integrated Search and Indexing
-//@line 449 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 449 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // -- Windows Search/Spotlight logging options
-//@line 464 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 464 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // Whether to use a panel that looks like an OS X sheet for customization
-//@line 469 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 469 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 pref("toolbar.customization.usesheet", false);
-//@line 471 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 471 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // Check for missing attachments?
 pref("mail.compose.attachment_reminder", true);
@@ -435,13 +435,13 @@ pref("mail.compose.attachment_reminder_keywords", "chrome://messenger/locale/mes
 pref("mail.compose.attachment_reminder_aggressive", true);
 
 pref("browser.formfill.enable", true);
-//@line 482 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 482 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 // Override the all.js values so that unit tests pass and we get sane values.
 pref("browser.formfill.expire_days", 180);
 pref("browser.history_expire_days", 180);
 pref("browser.history_expire_days_min", 90);
 pref("browser.history_expire_sites", 40000);
-//@line 488 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 488 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // Disable autoplay as we don't handle audio elements in emails very well.
 // See bug 515082.
@@ -466,13 +466,13 @@ pref("font.default", "sans-serif");
 pref("font.default.x-unicode", "sans-serif");
 pref("font.default.x-western", "sans-serif");
 
-//@line 527 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 527 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 // Since different versions of Windows need different settings, we'll handle
 // this in mailMigrator.js.
 
 // Linux, in other words.  Other OSes may wish to override.
-//@line 533 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 533 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 // The font.name-list fallback is defined in case font.name isn't
 // present -- e.g. in case a profile that's been used on Windows Vista or above
 // is used on Linux.
@@ -483,7 +483,7 @@ pref("font.name-list.monospace.x-unicode", "monospace");
 pref("font.name-list.serif.x-western", "serif");
 pref("font.name-list.sans-serif.x-western", "sans-serif");
 pref("font.name-list.monospace.x-western", "monospace");
-//@line 544 "/usr/obj/i386/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/app/profile/all-thunderbird.js"
+//@line 544 "/usr/obj/ports/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/app/profile/all-thunderbird.js"
 
 pref("mail.font.windows.version", 0);
 
@@ -511,3 +511,7 @@ pref("browser.link.open_newwindow", 3);
 pref("browser.link.open_newwindow.restriction", 0);
 
 pref("browser.tabs.loadDivertedInBackground", false);
+
+// Plugins are disabled due to a performance regression when they're on. See bug
+// 599119.
+pref("plugin.disable", true);
