@@ -231,13 +231,11 @@ function FinishAccount()
         EnableCheckMailAtStartUpIfNeeded(gCurrentAccount);
 
     if (!document.getElementById("downloadMsgs").hidden) {
+      // skip the default biff, we will load messages manually if needed
+      window.opener.gLoadStartFolder = false;
       if (document.getElementById("downloadMsgs").checked) {
         window.opener.gNewAccountToLoad = gCurrentAccount; // load messages for new POP account
       }
-      else if (gCurrentAccount == am.defaultAccount) {
-        // stop check for msgs when this is first account created from new profile
-        window.opener.gLoadStartFolder = false;
-      }
     }
 
     // in case we crash, force us a save of the prefs file NOW
@@ -306,7 +304,6 @@ function AccountDataToPageData(accountData, pageData)
     
     setPageData(pageData, "login", "username", server.username);
     setPageData(pageData, "login", "password", server.password);
-    setPageData(pageData, "login", "rememberPassword", server.rememberPassword);
     setPageData(pageData, "accname", "prettyName", server.prettyName);
     setPageData(pageData, "accname", "userset", false);
     setPageData(pageData, "ispdata", "supplied", false);
@@ -373,15 +370,13 @@ function PageDataToAccountData(pageData, accountData)
     }
     if (serverIsNntp(pageData)) {
         // this stuff probably not relevant
-        dump("not setting username/password/rememberpassword/etc\n");
+        dump("not setting username/password/etc\n");
     } else {
         if (pageData.login) {
             if (pageData.login.username)
                 server.username = pageData.login.username.value;
             if (pageData.login.password)
                 server.password = pageData.login.password.value;
-            if (pageData.login.rememberPassword)
-                server.rememberPassword = pageData.login.rememberPassword.value;
             if (pageData.login.smtpusername)
                 smtp.username = pageData.login.smtpusername.value;
         }
@@ -393,7 +388,7 @@ function PageDataToAccountData(pageData, accountData)
                 pageData.server.smtphostname.value)
                 smtp.hostname = pageData.server.smtphostname.value;
         }
-        if (pageData.identity.smtpServerKey)
+        if (pageData.identity && pageData.identity.smtpServerKey)
             identity.smtpServerKey = pageData.identity.smtpServerKey.value;
     }
 
@@ -408,32 +403,32 @@ function PageDataToAccountData(pageData, accountData)
 // (but don't fill in any fields, that's for finishAccount()
 function createAccount(accountData)
 {
+    // Retrieve the server (data) from the account data.
     var server = accountData.incomingServer;
     
     // for news, username is always null
     var username = (server.type == "nntp") ? null : server.username;
-
-    dump("am.createIncomingServer(" + username + "," +
-                                      server.hostName + "," +
-                                      server.type + ")\n");
-    
-    var server = am.createIncomingServer(username,
-                                         server.hostName,
-                                         server.type);
+    dump("am.createIncomingServer(" +
+         username + ", " + server.hostName + ", " + server.type + ")\n");
+    // Create a (actual) server.
+    server = am.createIncomingServer(username, server.hostName, server.type);
 
     dump("am.createAccount()\n");
+    // Create an account.
     var account = am.createAccount();
     
-    if (accountData.identity.email) // only create an identity for this account if we really have one (use the email address as a check)
+    // only create an identity for this account if we really have one
+    // (use the email address as a check)
+    if (accountData.identity && accountData.identity.email)
     {
         dump("am.createIdentity()\n");
+        // Create an identity.
         var identity = am.createIdentity();
     
-        /* new nntp identities should use plain text by default
-         * we want that GNKSA (The Good Net-Keeping Seal of Approval) */
-        if (server.type == "nntp") {
-			    identity.composeHtml = false;
-        }
+        // New nntp identities should use plain text by default;
+        // we want that GNKSA (The Good Net-Keeping Seal of Approval).
+        if (server.type == "nntp")
+          identity.composeHtml = false;
 
         account.addIdentity(identity);
     }
@@ -442,6 +437,7 @@ function createAccount(accountData)
     // tell RDF about the new server - it's not quite finished getting
     // set up yet, in particular, the deferred storage pref hasn't been set.
     server.valid = false;
+    // Set the new account to use the new server.
     account.incomingServer = server;
     server.valid = true;
     return account;
@@ -505,52 +501,28 @@ function finishAccount(account, accountData)
         if (destIdentity.attachSignature)
         {
             var sigFileName = accountData.signatureFileName;
-      
             var sigFile = gMailSession.getDataFilesDir("messenger");
             sigFile.append(sigFileName);
             destIdentity.signature = sigFile;
         }
 
-        // don't try to create an smtp server if we already have one.
-        if (!destIdentity.smtpServerKey)
+        if (accountData.smtp.hostname && !destIdentity.smtpServerKey)
         {
-            var smtpServer;
-        
-            /**
-             * Create a new smtp server if needed. If smtpCreateNewServer pref
-             * is set then createSmtpServer routine() will create one. Otherwise,
-             * default server is returned which is also set to create a new smtp server
-             * (via GetDefaultServer()) if no default server is found.
-             */
-            if (accountData.smtp.hostname != null)
-              smtpServer = smtpService.createSmtpServer();
-            else
-              smtpServer = smtpService.defaultServer;
+            // hostname + no key => create a new SMTP server.
 
-            // may not have a smtp server, see bug #138076
-            if (smtpServer) {
-              dump("Copying smtpServer (" + smtpServer + ") to accountData\n");
-              //set the smtp server to be the default only if it is not a redirectorType
-              if (accountData.smtp.redirectorType == null) 
-              {
-                if ((smtpService.defaultServer.hostname == null) || (smtpService.defaultServer.redirectorType != null))
-                  smtpService.defaultServer = smtpServer;
-              }
-
-              copyObjectToInterface(smtpServer, accountData.smtp, false);
-
-              // refer bug#141314
-              // since we clone the default smtpserver with the new account's username
-              // force every account to use the smtp server that was created or assigned to it in the
-              // case of isps using rdf files
-              try{
-                destIdentity.smtpServerKey = smtpServer.key;
-              }
-              catch(ex)
-              {
-                dump("There is no smtp server assigned to this account: Exception= "+ex+"\n");
-              }
+            var smtpServer = smtpService.createSmtpServer();
+            var isDefaultSmtpServer;
+            if (!smtpService.defaultServer.hostname) {
+              smtpService.defaultServer = smtpServer;
+              isDefaultSmtpServer = true;
             }
+
+            copyObjectToInterface(smtpServer, accountData.smtp, false);
+
+            // If it's the default server we created, make the identity use
+            // "Use Default" by default.
+            destIdentity.smtpServerKey =
+              (isDefaultSmtpServer) ? "" : smtpServer.key;
          }
      } // if the account has an identity...
 
@@ -564,7 +536,7 @@ function finishAccount(account, accountData)
 // This routine skips any attribute that begins with ServerType- 
 function setGenericAttribute(dest, src, attribute)
 {
-  if (!(/^ServerType-/i.test(attribute)))
+  if (!(/^ServerType-/i.test(attribute)) && src[attribute])
   {
     switch (typeof src[attribute])
     {
@@ -578,7 +550,7 @@ function setGenericAttribute(dest, src, attribute)
         dest.setIntAttribute(attribute, src[attribute]);
         break;
       default:
-        dump('Error: No Generic attribute found for: ' +  typeof src[attribute] + '\n');
+        dump("Error: No Generic attribute " + attribute + " found for: " + dest + "\n");
         break;
     }
   }
@@ -625,8 +597,7 @@ function verifyLocalFoldersAccount()
     {
       // dump("Creating local mail account\n");
       // creates a copy of the identity you pass in
-      messengerMigrator = Components.classes["@mozilla.org/messenger/migrator;1"].getService(Components.interfaces.nsIMessengerMigrator);
-      messengerMigrator.createLocalMailAccount(false /* false, since we are not migrating */);
+      am.createLocalMailAccount();
       try {
         localMailServer = am.localFoldersServer;
       }
@@ -644,7 +615,10 @@ function setupCopiesAndFoldersServer(account, accountIsDeferred, accountData)
 {
   try {
     var server = account.incomingServer;
-    if (server.type == "rss")
+
+    // This function sets up the default send preferences. The send preferences
+    // go on identities, so there is no need to continue without any identities.
+    if (server.type == "rss" || account.identities.Count() == 0)
       return false;
     var identity = account.identities.QueryElementAt(0, Components.interfaces.nsIMsgIdentity);
     // For this server, do we default the folder prefs to this server, or to the "Local Folders" server
@@ -665,13 +639,13 @@ function setupCopiesAndFoldersServer(account, accountIsDeferred, accountData)
       }
       copiesAndFoldersServer = am.localFoldersServer;
     }
-	  
+
     setDefaultCopiesAndFoldersPrefs(identity, copiesAndFoldersServer, accountData);
 
   } catch (ex) {
     // return false (meaning we did not setupCopiesAndFoldersServer)
     // on any error
-    dump("Error setupCopiesAndFoldersServer" + ex + "\n");
+    dump("Error in setupCopiesAndFoldersServer: " + ex + "\n");
     return false;
   }
   return true;
@@ -698,7 +672,6 @@ function setDefaultCopiesAndFoldersPrefs(identity, server, accountData)
   // because we happen to be doing things that way, and if the user changes
   // that, it will work because to change the folder, it must be in rdf,
   // coming from the folder cache, in the worst case.
-  var folders = rootFolder.GetSubFolders();
   var msgFolder = rootFolder.QueryInterface(Components.interfaces.nsIMsgFolder);
 
   /** 
@@ -714,43 +687,44 @@ function setDefaultCopiesAndFoldersPrefs(identity, server, accountData)
   /* we use internal names known to everyone like Sent, Templates and Drafts */
   /* if folder names were already given in isp rdf, we use them,
      otherwise we use internal names known to everyone like Sent, Templates and Drafts */
-  
-  var draftFolder = (accountData.identity && accountData.identity.draftFolder ? accountData.identity.draftFolder : "Drafts");
-  var stationeryFolder = (accountData.identity && accountData.identity.stationeryFolder ? accountData.identity.stationeryFolder : "Templates");
-  var fccFolder = (accountData.identity && accountData.identity.fccFolder ? accountData.identity.fccFolder : "Sent");
+
+  // Note the capital F, D and S!
+  var draftFolder = (accountData.identity && accountData.identity.DraftFolder ?
+    accountData.identity.DraftFolder : "Drafts");
+  var stationeryFolder = (accountData.identity && accountData.identity.StationeryFolder ?
+    accountData.identity.StationeryFolder : "Templates");
+  var fccFolder = (accountData.identity && accountData.identity.FccFolder ?
+    accountData.identity.FccFolder : "Sent");
 
   identity.draftFolder = msgFolder.server.serverURI+ folderDelim + draftFolder;
   identity.stationeryFolder = msgFolder.server.serverURI+ folderDelim + stationeryFolder;
   identity.fccFolder = msgFolder.server.serverURI+ folderDelim + fccFolder;
-          
 
-  identity.fccFolderPickerMode = (accountData.identity && accountData.identity.fccFolder ? 1 : gDefaultSpecialFolderPickerMode);
-  identity.draftsFolderPickerMode = (accountData.identity && accountData.identity.draftFolder ? 1 : gDefaultSpecialFolderPickerMode);
-  identity.tmplFolderPickerMode = (accountData.identity && accountData.identity.stationeryFolder ? 1 : gDefaultSpecialFolderPickerMode);
+  // Note the capital F, D and S!
+  identity.fccFolderPickerMode = (accountData.identity &&
+    accountData.identity.FccFolder ? 1 : gDefaultSpecialFolderPickerMode);
+  identity.draftsFolderPickerMode = (accountData.identity &&
+    accountData.identity.DraftFolder ? 1 : gDefaultSpecialFolderPickerMode);
+  identity.tmplFolderPickerMode = (accountData.identity &&
+    accountData.identity.StationeryFolder ? 1 : gDefaultSpecialFolderPickerMode);
 }
 
 function AccountExists(userName,hostName,serverType)
 {
   var accountExists = false;
-  var accountManager = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
-  try {
-        var server = accountManager.findRealServer(userName,hostName,serverType,0);
-        if (server) {
-                accountExists = true;
-        }
-  }
-  catch (ex) {
-        accountExists = false;
-  }
-  return accountExists;
+  var accountManager = Components.classes["@mozilla.org/messenger/account-manager;1"]
+                                 .getService(Components.interfaces.nsIMsgAccountManager);
+
+  return accountManager.findRealServer(userName, hostName, serverType, 0);
 }
 
 function getFirstInvalidAccount()
 {
-    am = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
+    var am = Components.classes["@mozilla.org/messenger/account-manager;1"]
+                       .getService(Components.interfaces.nsIMsgAccountManager);
 
     var invalidAccounts = getInvalidAccounts(am.accounts);
-  
+
     if (invalidAccounts.length > 0)
         return invalidAccounts[0];
     else
@@ -964,7 +938,12 @@ function FixupAccountDataForIsp(accountData)
       return;
 
     var email = accountData.identity.email;
-       
+
+    // The identity might not have an email address, which is what the rest of
+    // this function is looking for.
+    if (!email)
+      return;
+
     // fix up the username
     if (!accountData.incomingServer.username)
         accountData.incomingServer.username = getUsernameFromEmail(email, accountData.incomingServerUserNameRequiresDomain);
@@ -974,7 +953,8 @@ function FixupAccountDataForIsp(accountData)
       // fix for bug #107953
       // if incoming hostname is same as smtp hostname
       // use the server username (instead of the email username)
-      if (accountData.smtp.hostname == accountData.incomingServer.hostName)
+      if (accountData.smtp.hostname == accountData.incomingServer.hostName &&
+          accountData.smtpUserNameRequiresDomain == accountData.incomingServerUserNameRequiresDomain)
         accountData.smtp.username = accountData.incomingServer.username;
       else
         accountData.smtp.username = getUsernameFromEmail(email, accountData.smtpUserNameRequiresDomain);
