@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/mailCore.js"
+//@line 39 "/usr/obj/i386/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/base/content/mailCore.js"
 
 /*
  * Core mail routines used by all of the major mail windows (address book, 3-pane, compose and stand alone message window).
@@ -191,17 +191,21 @@ function MailToolboxCustomizeDone(aEvent, customizePopupId)
   if (this.UpdateMailToolbar != undefined)
     UpdateMailToolbar(focus);
 
-  document.getElementById("header-view-toolbox").removeAttribute("doCustomization");
+  var toolbox = document.getElementsByAttribute("doCustomization", "true")[0];
+  if (toolbox) {
+    toolbox.removeAttribute("doCustomization");
 
-  // The GetMail button is stuck in a strange state right now, since the
-  // customization wrapping preserves its children, but not its initialized
-  // state. Fix that here.
-  if (document.getElementById("button-getmsg")) {
-    // We can't use _teardown here, because it'll remove the Get All menuitem
-    let popup = document.getElementById("button-getMsgPopup");
-    let sep = document.getElementById("button-getAllNewMsgSeparator");
-    while (popup.lastChild != sep)
-      popup.removeChild(popup.lastChild);
+    // The GetMail button is stuck in a strange state right now, since the
+    // customization wrapping preserves its children, but not its initialized
+    // state. Fix that here.
+    // Fix Bug 565045: Only treat "Get Message Button" if it is in our toolbox
+    var popup = toolbox.getElementsByAttribute("id", "button-getMsgPopup")[0];
+    if (popup) {
+      // We can't use _teardown here, because it'll remove the Get All menuitem
+      let sep = toolbox.getElementsByAttribute("id", "button-getAllNewMsgSeparator")[0];
+      while (popup.lastChild != sep)
+        popup.removeChild(popup.lastChild);
+    }
   }
   UpdateJunkButton();
   UpdateReplyButtons();
@@ -389,9 +393,9 @@ function SetBusyCursor(window, enable)
 
 function openAboutDialog()
 {
-//@line 442 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/mailCore.js"
+//@line 446 "/usr/obj/i386/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/base/content/mailCore.js"
   window.openDialog("chrome://messenger/content/aboutDialog.xul", "About", "centerscreen,chrome,resizable=no");
-//@line 444 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/mailCore.js"
+//@line 448 "/usr/obj/i386/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/base/content/mailCore.js"
 }
 
 /**
@@ -423,13 +427,13 @@ function openFormattedURL(aPrefName)
   protocolSvc.loadURI(uri);
 }
 
-//@line 478 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/mailCore.js"
+//@line 482 "/usr/obj/i386/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/base/content/mailCore.js"
 
 function getMostRecentMailWindow() {
   let wm = Cc["@mozilla.org/appshell/window-mediator;1"]
              .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 484 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/mailCore.js"
+//@line 488 "/usr/obj/i386/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/base/content/mailCore.js"
   let win = wm.getMostRecentWindow("mail:3pane", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -443,7 +447,7 @@ function getMostRecentMailWindow() {
         win = nextWin;
     }
   }
-//@line 510 "/usr/obj/ports/mozilla-thunderbird-3.1.1/comm-1.9.2/mail/base/content/mailCore.js"
+//@line 514 "/usr/obj/i386/mozilla-thunderbird-3.1.7/comm-1.9.2/mail/base/content/mailCore.js"
 
   return win;
 }
